@@ -141,19 +141,6 @@ class Mesh(FromToPickle,
 
     Examples
     --------
-    .. plot::
-        :include-source:
-
-        import compas
-        from compas.datastructures import Mesh
-
-        mesh = Mesh.from_obj(compas.get('faces.obj'))
-
-        mesh.plot(
-            vertextext={key: key for key in mesh.vertices()},
-            vertexcolor={key: '#ff0000' for key in mesh.vertices_where({'vertex_degree': 2})},
-            vertexsize=0.2
-        )
 
     """
 
@@ -1077,7 +1064,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1099,7 +1086,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1165,7 +1152,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1208,7 +1195,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1578,7 +1565,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1716,7 +1703,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1805,7 +1792,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -1922,7 +1909,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -2138,7 +2125,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -2165,6 +2152,41 @@ class Mesh(FromToPickle,
                 nbrs.append(nbr)
         return nbrs
 
+    def face_neighborhood(self, key, ring=1):
+        """Return the faces in the neighborhood of a face.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the face.
+        ring : int, optional
+            The size of the neighborhood.
+            Default is ``1``.
+
+        Returns
+        -------
+        list
+            A list of face identifiers.
+
+        """
+
+        nbrs = set(self.face_neighbors(key))
+
+        i = 1
+        while True:
+            if i == ring:
+                break
+
+            temp = []
+            for key in nbrs:
+                temp += self.face_neighbors(key)
+
+            nbrs.update(temp)
+
+            i += 1
+
+        return list(nbrs)
+
     def face_degree(self, fkey):
         """Count the neighbors of a face.
 
@@ -2425,7 +2447,7 @@ class Mesh(FromToPickle,
 
             import compas
             from compas.datastructures import Mesh
-            from compas.plotters import MeshPlotter
+            from compas_plotters import MeshPlotter
 
             mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -2530,6 +2552,8 @@ class Mesh(FromToPickle,
 
         References
         ----------
+        Based on [1]_
+
         .. [1] Botsch, Mario, et al. *Polygon mesh processing.* AK Peters/CRC Press, 2010.
 
         """
@@ -2703,11 +2727,15 @@ class Mesh(FromToPickle,
                Available at: https://en.wikipedia.org/wiki/Types_of_mesh.
 
         """
-
         ideal_angle = 180 * (1 - 2 / float(len(self.face_vertices(fkey))))
-
-        angles = [angle_points(self.vertex_coordinates(v), self.vertex_coordinates(u), self.vertex_coordinates(w), deg = True) for u, v, w in window(self.face_vertices(fkey) + self.face_vertices(fkey)[:2], n = 3)]
-
+        angles = []
+        vertices = self.face_vertices(fkey)
+        for u, v, w in window(vertices + vertices[:2], n=3):
+            o = self.vertex_coordinates(v)
+            a = self.vertex_coordinates(u)
+            b = self.vertex_coordinates(w)
+            angle = angle_points(o, a, b, deg=True)
+            angles.append(angle)
         return max((max(angles) - ideal_angle) / (180 - ideal_angle), (ideal_angle - min(angles)) / ideal_angle)
 
     def face_curvature(self, fkey):
@@ -2724,21 +2752,14 @@ class Mesh(FromToPickle,
             The dimensionless curvature.
 
         """
-
-        plane = bestfit_plane([self.vertex_coordinates(vkey) for vkey in self.vertices()])
-
-        max_deviation = max([distance_point_plane(self.vertex_coordinates(vkey), plane) for vkey in self.vertices()])
-
-        average_distances = average([distance_point_point(self.vertex_coordinates(vkey), self.face_centroid(fkey)) for vkey in self.vertices()])
-
+        vertices = self.face_vertices(fkey)
+        points = [self.vertex_coordinates(key) for key in vertices]
+        centroid = self.face_centroid(fkey)
+        plane = bestfit_plane(points)
+        max_deviation = max([distance_point_plane(point, plane) for point in points])
+        average_distances = average([distance_point_point(point, centroid) for point in points])
         return max_deviation / average_distances
 
-    # def face_circle(self, fkey):
-    #     pass
-
-    # def face_frame(self, fkey):
-    #     pass
-
     # --------------------------------------------------------------------------
     # boundary
     # --------------------------------------------------------------------------
@@ -2869,7 +2890,6 @@ class Mesh(FromToPickle,
         boundary_edges : list
             The boundary edges.
 
-
         """
         boundary_edges =  [(u, v) for u, v in self.edges() if self.is_edge_on_boundary(u, v)]
 
@@ -2878,7 +2898,6 @@ class Mesh(FromToPickle,
         else:
             return [(u, v) if self.halfedge[u][v] is None else (v, u) for u, v in boundary_edges]
 
-
     # --------------------------------------------------------------------------
     # attributes
     # --------------------------------------------------------------------------
@@ -3091,72 +3110,6 @@ class Mesh(FromToPickle,
 
         return [self.get_edge_attributes(key, names, values) for key in keys]
 
-    # --------------------------------------------------------------------------
-    # visualisation
-    # --------------------------------------------------------------------------
-
-    def plot(self,
-             vertexcolor=None,
-             edgecolor=None,
-             facecolor=None,
-             vertexsize=None,
-             edgewidth=None,
-             vertextext=None,
-             edgetext=None,
-             facetext=None):
-        """Plot a 2D representation of the mesh.
-
-        Parameters
-        ----------
-        vertexcolor : dict, optional
-            A dictionary mapping vertex identifiers to colors.
-        edgecolor : dict, optional
-            A dictionary mapping edge identifiers to colors.
-        facecolor : dict, optional
-            A dictionary mapping face identifiers to colors.
-        vertexsize : dict, optional
-            A dictionary mapping vertex identifiers to sizes.
-        edgewidth : dict, optional
-            A dictionary mapping edge identifiers to widths.
-        vertextext : dict, optional
-            A dictionary mappping vertex identifiers to labels.
-        edgetext : dict, optional
-            A dictionary mappping edge identifiers to labels.
-        facetext : dict, optional
-            A dictionary mappping face identifiers to labels.
-
-        Examples
-        --------
-        .. plot::
-            :include-source:
-
-            import compas
-            from compas.datastructures import Mesh
-
-            mesh = Mesh.from_obj(compas.get('faces.obj'))
-
-            mesh.plot()
-
-        """
-        from compas.plotters import MeshPlotter
-
-        plotter = MeshPlotter(self)
-        plotter.draw_vertices(
-            facecolor=vertexcolor,
-            radius=vertexsize,
-            text=vertextext
-        )
-        plotter.draw_edges(
-            color=edgecolor,
-            width=edgewidth,
-            text=edgetext
-        )
-        plotter.draw_faces(
-            facecolor=facecolor,
-            text=facetext
-        )
-        plotter.show()
-
 
 # ==============================================================================
 # Main
@@ -3164,98 +3117,4 @@ class Mesh(FromToPickle,
 
 if __name__ == '__main__':
 
-    import compas
-    from compas.plotters import MeshPlotter
-
-    mesh = Mesh.from_obj(compas.get('faces.obj'))
-
-    mesh.update_default_edge_attributes({'q': 1.0})
-
-    # vertices = [
-    #     [0, 0, 0],
-    #     [1, 1, 0],
-    #     [1, -1, 0],
-    #     [-1, -1, 0],
-    #     [-1, 1, 0]
-    # ]
-    # faces = [
-    #     [0, 2, 1],
-    #     [0, 4, 3]
-    # ]
-
-    # mesh = Mesh.from_vertices_and_faces(vertices, faces)
-
-    # print(mesh.is_manifold())
-
-    # # mesh = Mesh()
-
-    # # a = mesh.add_vertex(x=0, y=0)
-    # # b = mesh.add_vertex(x=0.5, y=0.1)
-    # # c = mesh.add_vertex(x=1, y=0)
-    # # d = mesh.add_vertex(x=0.9, y=0.5)
-    # # e = mesh.add_vertex(x=0.9, y=1)
-    # # f = mesh.add_vertex(x=0.5, y=1)
-    # # g = mesh.add_vertex(x=0, y=1)
-    # # h = mesh.add_vertex(x=0, y=0.5)
-
-    # # mesh.add_face([a, b, c, d, e, f, g, h])
-
-    # for k in mesh.faces():
-    #     print(k, mesh.is_face_on_boundary(k))
-
-
-    # print(list(mesh.edges(True)))
-
-
-    # plotter = MeshPlotter(mesh)
-
-    # plotter.draw_vertices()
-    # plotter.draw_edges()
-    # plotter.draw_faces(text='key')
-    # plotter.show()
-
-    # print(mesh.get_vertices_attribute('x'))
-    # print(mesh.get_vertices_attributes('xy'))
-
-    # print(mesh.get_edges_attribute('q', 1.0))
-    # print(mesh.get_edges_attributes('qf', (1.0, 2.0)))
-
-    vertices = {
-        0: [0, 0, 0],
-        1: [1, 1, 0],
-        2: [1, -1, 0],
-        3: [-1, -1, 0],
-        18: [-1, 1, 0]
-    }
-    faces = {
-        0: [0, 2, 1],
-        45: [0, 18, 3]
-    }
-
-    mesh = Mesh.from_vertices_and_faces(vertices, faces)
-
-    plotter = MeshPlotter(mesh)
-    plotter.draw_vertices(text='key')
-    plotter.draw_edges()
-    plotter.draw_faces(text='key')
-    plotter.show()
-
-    vertices = [
-        [0, 0, 0],
-        [1, 1, 0],
-        [1, -1, 0],
-        [-1, -1, 0],
-        [-1, 1, 0]
-    ]
-    faces = [
-        [0, 2, 1],
-        [0, 4, 3]
-    ]
-
-    mesh = Mesh.from_vertices_and_faces(vertices, faces)
-
-    plotter = MeshPlotter(mesh)
-    plotter.draw_vertices(text='key')
-    plotter.draw_edges()
-    plotter.draw_faces(text='key')
-    plotter.show()
+    pass
