@@ -111,7 +111,7 @@ def trimesh_split_edge(mesh, u, v, t=0.5, allow_boundary=False):
         from compas.datastructures import Mesh
         from compas.datastructures import mesh_quads_to_triangles
         from compas.datastructures import trimesh_split_edge
-        from compas.plotters import MeshPlotter
+        from compas_plotters import MeshPlotter
 
         mesh = Mesh.from_obj(compas.get('faces.obj'))
 
@@ -224,7 +224,7 @@ if __name__ == "__main__":
 
     import compas
     from compas.datastructures import Mesh
-    from compas.plotters import MeshPlotter
+    from compas_plotters import MeshPlotter
     from compas.datastructures import mesh_quads_to_triangles
     from compas.datastructures import trimesh_split_edge
 
