@@ -2,7 +2,15 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import compas
+from numpy import asarray
+from numpy import sqrt
+from numpy import mean
+from numpy import sum
+from numpy import zeros
+from numpy.linalg import lstsq
+
+from scipy.linalg import svd
+from scipy.optimize import leastsq
 
 # should this not be defined in a different location?
 from compas.geometry import local_coords_numpy
@@ -10,21 +18,6 @@ from compas.geometry import global_coords_numpy
 
 from compas.numerical import pca_numpy
 
-try:
-    from numpy import asarray
-    from numpy import sqrt
-    from numpy import mean
-    from numpy import sum
-    from numpy import zeros
-    from numpy.linalg import lstsq
-
-    from scipy.linalg import svd
-    from scipy.optimize import leastsq
-
-
-except ImportError:
-    compas.raise_if_not_ironpython()
-
 
 __all__ = [
     'bestfit_plane_numpy',
