@@ -57,7 +57,11 @@ __all__ = [
     'mirror_points_line_xy',
     'mirror_points_plane',
 
+    'project_point_plane',
+
     'project_points_plane',
+    'project_point_line',
+    'project_point_line_xy',
     'project_points_line',
     'project_points_line_xy',
 
