@@ -2,14 +2,8 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import compas
-
-try:
-    from numpy import asarray
-    from scipy.linalg import svd
-
-except ImportError:
-    compas.raise_if_not_ironpython()
+from numpy import asarray
+from scipy.linalg import svd
 
 
 __all__ = ['pca_numpy']
@@ -20,7 +14,8 @@ def pca_numpy(data):
 
     Parameters
     ----------
-    data : list
+    data : listpython
+
         A list of `m` observations, measuring `n` variables.
         For example, if the data are points in 2D space, the data parameter
         should contain `m` nested lists of `2` variables, the `x` and `y`
@@ -43,47 +38,6 @@ def pca_numpy(data):
 
     Examples
     --------
-    .. plot::
-        :include-source:
-
-        from numpy import random
-
-        import matplotlib.pyplot as plt
-
-        from compas.geometry import matrix_from_axis_and_angle
-        from compas.geometry import transform_points_numpy
-
-        from compas.plotters import Axes3D
-        from compas.plotters import Cloud3D
-        from compas.plotters import Bounds
-        from compas.plotters import create_axes_3d
-
-        from compas.numerical import pca_numpy
-
-        data = random.rand(300, 3)
-        data[:, 0] *= 10.0
-        data[:, 1] *= 1.0
-        data[:, 2] *= 4.0
-
-        a = 3.14159 * 30.0 / 180
-        Ry = matrix_from_axis_and_angle([0, 1.0, 0.0], a, rtype='array')
-
-        a = -3.14159 * 45.0 / 180
-        Rz = matrix_from_axis_and_angle([0, 0, 1.0], a, rtype='array')
-
-        R = Rz.dot(Ry)
-
-        data = transform_points_numpy(data, R)
-
-        average, vectors, values = pca_numpy(data)
-
-        axes = create_axes_3d()
-
-        Bounds(data).plot(axes)
-        Cloud3D(data).plot(axes)
-        Axes3D(average, vectors).plot(axes)
-
-        plt.show()
 
     """
     X = asarray(data)
@@ -151,10 +105,10 @@ if __name__ == "__main__":
     from compas.geometry import matrix_from_axis_and_angle
     from compas.geometry import transform_points_numpy
 
-    from compas.plotters import Axes3D
-    from compas.plotters import Cloud3D
-    from compas.plotters import Bounds
-    from compas.plotters import create_axes_3d
+    from compas_plotters import Axes3D
+    from compas_plotters import Cloud3D
+    from compas_plotters import Bounds
+    from compas_plotters import create_axes_3d
 
     data = random.rand(300, 3)
     data[:, 0] *= 10.0
