@@ -15,7 +15,10 @@ except ImportError:
     from xmlrpc.client import ServerProxy
 
 try:
-    from subprocess import Popen, PIPE, STDOUT
+    from subprocess import Popen
+    from subprocess import PIPE
+    from subprocess import STDOUT
+
 except ImportError:
     try:
         from System.Diagnostics import Process
@@ -359,22 +362,12 @@ if __name__ == "__main__":
     import sys
 
     from compas.datastructures import Mesh
-    from compas.plotters import MeshPlotter
-    # from compas_rhino.artists import MeshArtist
-
     from compas.rpc import Proxy
 
+    from compas_rhino.artists import MeshArtist
+
     numerical = Proxy('compas.numerical')
 
-    # numerical.stop_server()
-    # numerical.start_server()
-
-    print(sys.version_info)
-
-    print(numerical.python)
-    print(numerical.address)
-    print(numerical.service)
-
     mesh = Mesh.from_obj(compas.get('faces.obj'))
 
     mesh.update_default_vertex_attributes({'px': 0.0, 'py': 0.0, 'pz': 0.0})
@@ -403,14 +396,8 @@ if __name__ == "__main__":
         attr['f'] = f[index][0]
         attr['l'] = l[index][0]
 
-    plotter = MeshPlotter(mesh, figsize=(10, 7))
-    plotter.draw_vertices()
-    plotter.draw_faces()
-    plotter.draw_edges()
-    plotter.show()
-
-    # artist = MeshArtist(mesh)
-    # artist.draw_vertices()
-    # artist.draw_edges()
-    # artist.draw_faces()
-    # artist.redraw()
+    artist = MeshArtist(mesh)
+    artist.draw_vertices()
+    artist.draw_edges()
+    artist.draw_faces()
+    artist.redraw()
